@@ -156,7 +156,8 @@ $catalogue = new MessageCatalogue('en', array (
     'shopware.installer.start' => 'Start',
     'shopware.installer.start_installation' => 'Start installation',
     'shopware.installer.select_language_de' => 'German',
-    'shopware.installer.select_language_en' => 'English',
+    'shopware.installer.select_language_en' => 'English (United Kingdom)',
+    'shopware.installer.select_language_us' => 'English (United States of America)',
     'shopware.installer.select_language_nl' => 'Dutch',
     'shopware.installer.select_language_it' => 'Italian',
     'shopware.installer.select_language_fr' => 'French',
@@ -178,7 +179,7 @@ $catalogue = new MessageCatalogue('en', array (
     'shopware.installer.select_country_fin' => 'Finland',
     'shopware.installer.select_country_isr' => 'Israel',
     'shopware.installer.select_country_bel' => 'Belgium',
-    'shopware.installer.select_country_usa' => 'United States',
+    'shopware.installer.select_country_usa' => 'United States of America',
     'shopware.installer.select_country_lie' => 'Liechtenstein',
     'shopware.installer.select_country_pol' => 'Poland',
     'shopware.installer.select_country_nam' => 'Namibia',
@@ -464,6 +465,11 @@ $catalogue = new MessageCatalogue('en', array (
     'shopware.installer.database-configuration_field_ssl_cert_path' => 'SSL certificate path',
     'shopware.installer.database-configuration_field_ssl_cert_key_path' => 'SSL certificate key path',
     'shopware.installer.database-configuration_field_ssl_dont_verify_cert' => 'Don\'t verify server certificate',
+    'shopware.installer.database-configuration_fetch_error' => 'An error occurred while fetching the database information',
+    'shopware.installer.database-configuration_access_denied' => 'Access denied, credentials are incorrect',
+    'shopware.installer.database-configuration_host_not_found' => 'Could not connect to database server',
+    'shopware.installer.database-configuration_invalid_requirements' => 'Shopware 6 requires at least MySQL 5.7.21 or MariaDB 10.3.22',
+    'shopware.installer.database-configuration_refresh_databases' => 'Refresh Databases',
     'shopware.installer.database-import_header' => 'Installation',
     'shopware.installer.database-import_skip_import' => 'Skip',
     'shopware.installer.database-import_progress' => 'Progress: ',
